<!--
 * @Author: ChenXiaolei
 * @Date: 2022-01-18 18:52:26
 * @LastEditTime: 2023-10-19 17:03:29
 * @LastEditors: ChenXiaolei
 * @Description: 
-->
# seven_studio

## 天志互联Python公共基础后台管理平台

### 1.5.2 更新内容
* 限制弱密码输入

### 1.5.0 更新内容
* 修改登录过滤器login_filter

### 1.4.0 更新内容
* 优化配置文件
* 修改json_dumps

### 1.3.2 更新内容
* 登录问题修改

### 1.2.0 更新内容
* GetUserInfoHandler增加字段返回

### 1.1.9 更新内容
* 基础配置更新
* 用户登录过期处理

### 1.1.8 更新内容
* 用户登录过期

### 1.1.6 更新内容
* 复制黏贴栏目修复
* 过滤器、快速添加按钮修复

### 1.1.4 更新内容
* 跨域允许PATCH访问

### 1.1.3 更新内容
* 修复aws S3 bug

### 1.1.2 更新内容
* 修复aws S3 bug

### 1.1.1 更新内容
* http多支持PUT、DELETE

### 1.1.0 更新内容
* redis支持ssl

### 1.0.15 更新内容
* 挂载栏目权限问题修复

### 1.0.14 更新内容
* 添加百度云存储

### 1.0.13 更新内容
* 调整用户登录,去掉平台登录错误的提示

### 1.0.12 更新内容
* 添加顶部菜单栏,服务端调整

### 1.0.11 更新内容
* 栏目删除优化

### 1.0.10 更新内容
* 优化行为日志

### 1.0.9 更新内容
* 增加行为日志

### 1.0.8 更新内容
* 增加腾讯云存储

### 1.0.6 更新内容
* 注释格式修改
* monitor迁移至内容管理平台基础框架

### 1.0.5 更新内容
* 增加oss2上传配置

### 1.0.3 更新内容
* 项目整理

### 1.0.2 更新内容
* 项目整理

### 1.0.1 更新内容
* bug修复

### 1.0.0 更新内容
* 项目创建